IsCamelCaseExtension extension
Extension for lower camel case
- on
Properties
- isCamelCase → bool
-
Available on String, provided by the IsCamelCaseExtension extension
Returns true if the string is lower camel caseno setter
Extension for lower camel case
Available on String, provided by the IsCamelCaseExtension extension
Returns true if the string is lower camel case