smartMaster property
If smartMaster is set this node will automatically connect to the smartMaster and take over it's values once it is available.
Implementation
List<String> get smartMaster => canBeSmart ? _smartMaster : const [];
If smartMaster is set this node will automatically connect to the smartMaster and take over it's values once it is available.
List<String> get smartMaster => canBeSmart ? _smartMaster : const [];