ExampleChildScBuilderBluePrint class
An example builder
- Inheritance
-
- Object
- ScBuilderBluePrint
- ExampleChildScBuilderBluePrint
Constructors
- ExampleChildScBuilderBluePrint({String key = 'exampleChildScBuilder'})
-
The constructor
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The key of the builder
finalinherited
-
needsUpdateSuppliers
→ List<
String> -
When one of these suppliers change, the rebuild method will be called
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addNodes(
{required Scope hostScope}) → List< NodeBluePrint> -
Override this method to add nodes to a given host scope
inherited
-
addScopes(
{required Scope hostScope}) → List< ScopeBluePrint> -
Override this method to add scopes to the given host scope
inherited
-
children(
{required Scope hostScope}) → List< ScBuilderBluePrint> -
A builder can define builders for child scopes
inherited
-
inserts(
{required Node hostNode}) → List< NodeBluePrint> -
Inserts
Will an insert "c0MultiplyByTwo" to all nodes starting with host
override
-
instantiate(
{required Scope scope, ScBuilder? parent}) → ScBuilder -
Instantiates this builder and it's children within the given hostScope
inherited
-
needsUpdate(
{required Scope hostScope, required List components}) → void -
Override this method to react to do something when one of the suppliers
in needsUpdateSuppliers has a new product.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onInstantiate(
{required Scope hostScope}) → void -
Override this method to react to the instantiation of the builder
inherited
-
replaceNode(
{required Scope hostScope, required Node nodeToBeReplaced}) → NodeBluePrint -
Override this method to replace a scope in a given host scope
inherited
-
replaceScope(
{required Scope hostScope, required ScopeBluePrint scopeToBeReplaced}) → ScopeBluePrint -
Override this method to replace scopes in the given host scope
inherited
-
shouldProcessChildren(
Scope scope) → bool -
Determines whether the builder should process a scope's children
override
-
shouldProcessScope(
Scope scope) → bool -
Determines whether the builder should process a scope
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited